@@ -51,16 +51,39 @@ class QualityChecker(object):
             return True
         except ValueError:
             return False
+        
+    
+    @staticmethod
+    def _str_to_bool(boolstr):
+        if boolstr == 'True':
+            return True
+        return False
 
     def _apply_date_validation(self, node) -> Tuple[str, bool]:
         column_name = self._treat_column_name(node.children[0])
-        if len(node.children) == 1:
-            pass_percent = 100
-        else:
+        pass_percent = 100
+        ignore_nulls = False
+        if len(node.children) == 3:
             pass_percent = int(node.children[1])
+            ignore_nulls = self._str_to_bool(node.children[2])
 
-        valid_dates = self._obj.loc[self._obj[column_name].apply(self._is_date)]
-        return node.data, (valid_dates.shape[0]/self._obj.shape[0])*100 >= pass_percent
+        if len(node.children) == 2:
+            c = node.children[1]
+            if c.type == 'PERCENT':
+                pass_percent = int(c.value)
+            if c.type == 'BOOL':
+                ignore_nulls = self._str_to_bool(c.value)
+
+
+        non_null_rows = self._obj[self._obj[column_name].notnull()]
+        valid_dates = non_null_rows[non_null_rows[column_name].apply(self._is_date)]
+        if not ignore_nulls:
+            return node.data, (valid_dates.shape[0]/self._obj.shape[0])*100 >= pass_percent
+        else:
+            if (non_null_rows.shape[0] > 0):
+                return node.data, (valid_dates.shape[0]/non_null_rows.shape[0])*100 >= pass_percent
+
+        return node.data, False
 
     def _apply_has_one_of(self, node) -> Tuple[str, bool]:
         column_name = self._treat_column_name(node.children[0])
@@ -98,7 +121,13 @@ class QualityChecker(object):
             not_na_df = self._obj
 
         passing = not_na_df[not_na_df['length'] == rhs]
-        return node.data, (passing.shape[0]/self._obj.shape[0])*100 >= percent
+        if not ignore_nulls:
+            return node.data, (passing.shape[0]/self._obj.shape[0])*100 >= percent
+        else:
+            if (not_na_df.shape[0] > 0):
+                return node.data, (passing.shape[0]/not_na_df.shape[0])*100 >= percent
+        
+        return node.data, False
 
     def _apply_has_columns(self, node) -> Tuple[str, bool]:
         column_names = [ct.value.replace("\"", "") for ct in node.children[0].children]
